Learn R Programming

growcurves (version 0.2.3.8)

getmf: Produce fixed and random effects design matrices from single formula input

Description

An internal function to dpgrow and dpgrowmm

Usage

getmf(formula, random.only, data, na.action)

Arguments

formula
A formula of format y ~ x_1 + x_2*x_3 | z_1*z_2 where | separates fixed (to the left of |) and random effects.
random.only
A boolean scalar used in the case that either fixed or random effects are entered in formula, but not both, which case the | is not entered (e.g. y ~ x_1 + x_2*x_3. Then, if random.only == TRUE
data
Associated data.frame containing names variables in formula
na.action
Should be left blank for use in dpgrow and dpgrowmm, where is automatically set to na.fail.

Value

  • res A list object containing list(y = y, x = x, z = z, m = m, mf = mf).

See Also

dpgrow dpgrowmm