Usage
mmCmvplusDpPost(y, X, Z, H, Wcase, Wsubject, Omega, omegaplus, groups, subjects,
niter, nburn, nthin, strength.mm, corsess, shapealph, ratebeta, typemm)
Arguments
y
An N x 1 response (of subject-measure
cases)
X
Fixed effects design matrix
Z
Random effects design matrix. Assumed grouped
by subjects
H
Multivariate MM effects design matrix.
Wcase
An N x 1 multiple membership weight
matrix to map supplemental random effects
Wsubject
An P.aff x S multiple membership
weight matrix with rows equal to number of unique
affected subjects
Omega
An S x S unnormalized adjacency
matrix with entries equal to 1 where two effects
communicate and 0, otherwise. Diagonal elements are
zero
omegaplus
S x 1 vector of row sums of
Omega
groups
S x 1 vector of group identifiers
for each effect. Effects within each group communicate.
Effects don't communicate across groups. Not used under
"mmi" prior (though input is required).
subjects
An N x 1 set of subject
identifiers
niter
The number of MCMC iterations
nburn
The number of MCMC burn-in iterations to
discard
nthin
The step increment of MCMC samples to
return
strength.mm
The shape and rate parameters for the
$\Gamma$ prior on the CAR precision parameter,
$\tau_{\gamma}$.
corsess
A single value to set the prior
correlations among the multivariate q = ncol(H)
orders for the MM effects. where $\tau_{\gamma}$ is
replaced by the q x q, $\Lambda$.
shapealph
The shape parameter for the $\Gamma$
prior on the DP concentration parameter. The rate
parameter is set of 1.
ratebeta
The rate parameter for the $\Gamma$
prior on the DP concentration parameter. Default value is
1.
typemm
An indicator the prior formulation
specified for the multivariate MM effects term. Set
typemm = 0 for "mmi" and typemm = 1
for "mmcar".