Usage
mmIplusDpPost(y, X, Z, Wcase, Wsubject, subjects, niter, nburn, nthin,
strength.mm, shapealph, ratebeta)
Arguments
y
An N x 1 response (of subject-measure
cases)
X
Fixed effects design matrix
Z
Random effects design matrix. Assumed grouped
by subjects
Wcase
An N x 1 multiple membership weight
matrix to map supplemental random effects
Wsubject
An P.aff x S multiple membership
weight matrix with rows equal to number of unique
affected subjects
subjects
An N x 1 set of subject
identifiers
niter
The number of MCMC iterations
nburn
The number of MCMC burn-in iterations to
discard
nthin
The step increment of MCMC samples to
return
strength.mm
The shape and rate parameters for the
$\Gamma$ prior on the CAR precision parameter,
$\tau_{\gamma}$
shapealph
The shape parameter for the $\Gamma$
prior on the DP concentration parameter. The rate
parameter is set of 1.
ratebeta
The rate parameter for the $\Gamma$
prior on the DP concentration parameter. Default value is
1.