datsim: Repeated measures for two groups of subjects drawn from mmcar model with no nuisance covariates
Description
A simulation dataset containing repeated subject measures
for 2 treatment groups, (control = 0, treatment = 1),
constructed from an mmcar model with correlation between
adjacent sessions equal to 0.25. Subject effects were
randomly drawn from 10 clusters with
weights/probabilities drawn from a Dirichlet
distribution. Cluster location values were generated
from a Gaussian base distribution.format
A list object of 19 variables for 792 total observations on 264 subjectsDetails
- y. response. there are
N = 792total measures forP = 264subjects - subject.
subject identifier
(1,2,...,264 - trt.
treatment group identifier of length
N(e.g.(0,0,0,...,1,1,1,...), either{0,1}for
control and treatment. - time. times in months for
each repeated subject measure of length
N. There
are 3 distinct time points. e.g.(0,3,6,0,3,6,0,0,3,,,,) - n.random. number of
random effects per subject. Set = 3.
- n.fix_degree. order of fixed effects. Set = 2, for
quadratic, meaning 3 effects (intercept, slope,
quadratic) each, for treatment and control groups.
- coefs. true fixed effect coefficient values used to
generate data.
- subj.aff. indexes subjects
receiving treatment.
- W.subj.aff. multiple
membership weight matrix that maps the
P_aff = 132affected subjects (insubj.aff) to any ofS
= 245treatment sessions. - group. treatment group
membership for each of the
Ssessions. - Omega. the
S x SCAR adjacency matrix used to
model prior dependence among sessions - gamma. true
session effect values (of length
S) used to
generate model response. - s. true cluster
memberships for each of the
Psubjects. - b.star. a list object of true cluster location values for
each of
M = 10clusters. Each entry contains then.random = 3location values for that cluster. - b. a list object true random effect coefficient
values for each of
Psubjects. Each entry
contains then.random = 3effect values for that
subject. - tau.b. true values for the prior
precisions of the base Gaussian distribution for each of
n.random = 3subject effects. - tau.e. true
value for overall model error.
- coefs. true
coefficient values for the time-based quadratic fixed
effects generated from the
trt, andtimeinputs. e.g. X =
c(1,time,time^2,trt_1,trt_1*time,trt_1*time^2).