datsimmult: Repeated measures for two groups of subjects with two multiple membership (MM) terms
Description
A simulation dataset containing repeated subject measures
for 2 treatment arms, (control = 0, treatment = 1),
constructed from a four- MM term multiple membership
model. MM terms 1 and 3 employ an 'mmi' prior over the
set of treatment groups, which are then linked back to
subjects with a weight matrix. MM terms 2 and 4 employ
an 'mmcar' prior over the number of treatment sessions
attended, with correlations between adjacent number of
sessions equal to 0.25. Subject effects were randomly
drawn from 10 clusters with assignment
weights/probabilities drawn from a Dirichlet
distribution. Cluster location values were generated
from a Gaussian base distribution.format
A list object of 22 variables for 897 total observations on 299 subjectsDetails
- y. response. there are
N = 897total measures forP = 299subjects - subject.
subject identifier
(1,2,...,299 - trt.
treatment group identifier of length
N(e.g.(0,0,0,...,1,1,1,...), either{0,1}for
control and treatment. - time. times in months for
each repeated subject measure of length
N. There
are 3 distinct time points. e.g.(0,3,6,0,3,6,0,0,3,,,,) - n.random. number of
random effects per subject. Set = 3.
- n.fix_degree. order of fixed effects. Set = 2, for
quadratic, meaning 3 effects (intercept, slope,
quadratic) each, for treatment and control groups.
- X The resultant
N x n.fixedfixed effects design
matrix.X = c(1, time, time^2, trt_1,trt_1*time,
trt_1*time^2, age, income). - coefs. true
coefficient values for the time-based quadratic fixed
effects generated from the
trt, andtimeinputs. - Z The resultant
N x n.randomby-subject random effects design matrix.Z = c(1,
time, time^2. - Z.b The
N x 1matrix [Z_{1}
* b_{1},...,Z_{n}*b_{n}]. wherenequals the
number of (unique) subjects. - subj.aff. A list
object with each term a vector that indexes
n[g]subjects linked to each ofg = 1, ..., (G = 4)CBT
therapy groups. Each group is specialized to its own
multiple membership (MM) term for employment of engine
functiondpgrowmmult. The number of treatment arm
subjects for each group are(n[1] = 17, n[2] = 18,
n[3] = 19, n[4] = 78)for a total ofPaff = 132subjects assigned to the treatment arm. - W.subj.aff. A list object containing
G, n[g] x
S[g]multiple membership weight matrices that together
map theP_aff = 132affected subjects (in each
element of thesubj.afflist) to their particular
sessions attended within their assigned group. There are
a total of 245 sessions allocated to theGgroups
asS[1] = 36, S[2] = 40, S[3] = 40, S[4] = 129. - group. A list object of length equal to the number
of MM terms under the 'mmcar' prior - In this case, terms
2 and 4. The elements in this list object contain a
vector of labels that align the MM effects in a given
term to disjoint, non-communicating groups. For these
data, there are no groupings, so the single entry in
'group' associated to the 'mmcar' prior on number of
sessions attended is filled with 1's equal to the number
of of MM effects in each term.
- Omega. A list
object containing an
S[g] x S[g]CAR adjacency
matrix used to model prior dependence among effects for
each MM term under the 'mmcar' prior, whereS[g]are the number of effects for termi. Here, there
are two terms (2 and 4) under "mmcar", soOmegacontains two elements. - us. A list object where
each element is a vector of true MM session effect values
for a given MM term. There are four MM terms in these
data, so there are 4 elements, each of length
S[g]. - s. A vector of true cluster
memberships for each of the
nsubjects. - b.star. A list object of true cluster location values for
each of
M = 10clusters. Each entry contains then.random = 3location values for that cluster. - b. A list object true random effect coefficient
values for each of
nsubjects. Each entry
contains then.random = 3effect values for that
subject. - coefs. A numeric vector of length
{n.fixed + 1} that contains the true fixed effects
coefficient values for the intercept plus the columns in
X(in order). - tau.b. true values for the
prior precisions of the base Gaussian distribution for
each of
n.random = 3subject effects. - tau.u. An
4 x 1vector of precision parameters
associated to the Gaussian prior formulations for each MM
term (under either 'mmcar' or 'mmi' covariance
constructions). - tau.e. true value for overall
model error.
- option. A character vector equal to
c("mmi","mmcar","mmi","mmcar")that presents the
prior formulations chosen for the 4 MM terms; The "mmi"
employs an independent Gaussian prior while the "mmcar"
allows for adjacency based dependence.