relabel: Relabel user vector input to sequential numerical
Description
Takes user input for vector in either character or
numerical format and converts it to sequential numeric
format. For use in functions requiring sequential
numerical format. Returns new sequential numerical
vector and vector of unique values inputted by user. The
latter is used to label plot variables returned to the
user.
Usage
relabel(label.input, start)
Arguments
label.input
A vector in numerical or character
format that the user desires to convert to sequential
numeric.
start
An integer representing the starting value
of the sequential sequence for the new label vector.
Value
A list object containing the new sequential vector,
label.new, and a vector of unique input values,
labeli.u.